@@ -62,7 +62,9 @@ class Neo4j(object):
             app.extensions = {}
         app.extensions['neo4j'] = self
 
-        app.config.setdefault('GRAPH_DATABASE', neo4j.DEFAULT_URI)
+        # Commented out due to Py2neo Issue:
+        # https://github.com/nigelsmall/py2neo/issues/193
+        # app.config.setdefault('GRAPH_DATABASE', neo4j.DEFAULT_URI)
 
         # Use the newstyle teardown_appcontext if it's available,
         # otherwise fall back to the request context
@@ -72,7 +74,7 @@ class Neo4j(object):
             app.teardown_request(self.teardown)
 
     def teardown(self, exception):
-        ctx = stack.top
+        ctx = stack.top # TODO clean up teardown related to graph_db behavior
         if hasattr(ctx, 'graph_db'):
             # py2neo does not have an 'open' connection that needs closing
             ctx.graph_db = None
@@ -87,42 +89,32 @@ class Neo4j(object):
 
         :return: the graph database service property
         """
-        self.graph_db = neo4j.GraphDatabaseService.get_instance(
-            self.app.config['GRAPH_DATABASE']
+        #self.graph_db = neo4j.GraphDatabaseService.get_instance(
+        self.graph_db = neo4j.GraphDatabaseService(
+            #self.app.config['GRAPH_DATABASE']
         )
-        print 'Connected to:', self.graph_db.neo4j_version
 
         if not hasattr(self, 'index'):
             self.index = {}
             # add all the indexes as app attributes
             if self._indexes is not None:
                 for i, i_type in self._indexes.iteritems():
-                    print 'getting or creating graph index:', i
+                    print 'getting or creating graph index:', i, i_type
                     self.index[i] = \
                         self.graph_db.get_or_create_index(i_type, i)
 
         return self.graph_db
 
-    # def _connect(self):
-    #     _gdb = neo4j.GraphDatabaseService.get_instance(
-    #         current_app.config['GRAPH_DATABASE']
-    #     )
-    #     print 'Connected to:', _gdb.neo4j_version
-    #     return _gdb
-    #
-    # @property
-    # def gdb(self):
-    #     ctx = stack.top
-    #     if ctx is not None:
-    #         if not hasattr(ctx, 'graph_db'):
-    #             ctx.graph_db = self._connect()
-    #         print 'past context setting...'
-    #         # add all the indexes as app attributes
-    #         if self._indexes is not None:
-    #             for i, i_type in self._indexes.iteritems():
-    #                 print 'getting or creating graph index:', i
-    #                 graph_index = ctx.graph_db.get_or_create_index(i_type, i)
-    #                 self.index[i] = graph_index
-    #                 graph_index = None
-    #
-    #     return ctx.graph_db
\ No newline at end of file
+if __name__ == '__main__':
+    #graph_db = neo4j.GraphDatabaseService()
+    #print graph_db
+    #print graph_db.neo4j_version
+    #foo = graph_db.get_or_create_index(neo4j.Node, 'Foo')
+    #print 'got Foo Index:', foo
+    #graph_db.delete_index(neo4j.Node, 'Foo')
+    from flask import Flask
+    app = Flask(__name__)
+    graph_indexes = {'Species': neo4j.Node}
+    n4j = Neo4j(app, graph_indexes)
+    print n4j.gdb.neo4j_version
+    species_index = n4j.index['Species']
\ No newline at end of file
